==> nextcloud-30.0.16.tar.bz2: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Activity feed" : "Sažetak aktivnosti",
    "Your settings have been updated." : "Vaše su postavke ažurirane.",
    "Settings have been updated." : "Postavke su ažurirane.",
    "Recent activity" : "Nedavna aktivnost",
    "No activities" : "Nema aktivnosti",
    "More activities" : "Više aktivnosti",
    "Daily activity summary for %s" : "Dnevni sažetak aktivnosti za %s",
    "All activities" : "Sve aktivnosti",
    "By others" : "Od drugih",
    "By you" : "Vaše",
    "Activity at %s" : "Aktivnost na %s",
    "Hello %s" : "Pozdrav %s",
    "Hello %s," : "Pozdrav %s",
    "There was some activity at %s" : "Bilo je aktivnosti na %s",
    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u <a href=\"%s\">postavkama</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u postavkama: %s",
    "Mail" : "Pošta",
    "Push" : "Push",
    "Activity" : "Aktivnost",
    "Notifications" : "Obavijesti",
    "This application enables people to view a log of activities about them, their files or other data." : "Ova aplikacija omogućuje korisnicima pregled aktivnosti o njima, njihovim datotekama ili ostalim podacima.",
    "Send email" : "Pošalji poruku e-pošte",
    "Send push notification" : "Pošalji \"push\" notifikaciju",
    "Activity notification configuration" : "Konfiguracija obavijesti o aktivnostima",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "You need to set up your email address before you can receive notification emails." : "Morate navesti svoju adresu e-pošte kako biste primali poruke s obavijestima.",
    "Send activity emails" : "Šalji e-poštu s pregledom aktivnosti",
    "As soon as possible" : "Čim prije moguće",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "You commented" : "Vi ste komentirali",
    "Message deleted by author" : "Autor je izbrisao poruku",
    "Open {filename}" : "Otvori {filename}",
    "in {path}" : "u {path}",
    "Home" : "Početna",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "No activity yet" : "Trenutno nema aktivnosti",
    "Activity settings" : "Postavke Aktivnosti",
    "Enable RSS feed" : "Omogući sažetak događaja RSS",
    "RSS feed" : "Sažetak događaja RSS",
    "Copy RSS feed link" : "Kopiraj poveznicu sažetka događaja.",
    "Personal notification settings" : "Osobne postavke obavijesti",
    "Unable to load the activity list" : "Nije moguće učitati popis aktivnosti",
    "Choose for which activities you want to get an email or push notification." : "Odaberite za koje aktivnosti želite primati obavijest e-poštom ili push obavijesti.",
    "Choose for which activities you want to get a push notification." : "Odaberite za koje aktivnosti želite primati push obavijesti.",
    "Notification" : "Obavijest",
    "Enable notification emails" : "Omogući e-poštu s obavijestima",
    "Daily activity summary" : "Dnevni sažetak aktivnosti",
    "Send daily activity summary in the morning" : "Šalji dnevni sažetak aktivnosti ujutro",
    "Default settings" : "Zadane postavke",
    "Configure the default notification settings for new accounts." : "Konfiguriraj zadane postavke obavijesti za nove račune.",
    "Unable to save the settings" : "Nije moguće spremiti postavke",
    "No more events to load" : "Nema više događaja za učitavanje"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-31.0.14.tar.bz2: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Activity feed for %1$s" : "Sažetak aktivnosti za %1$s",
    "Activity feed" : "Sažetak aktivnosti",
    "Your settings have been updated." : "Vaše su postavke ažurirane.",
    "Settings have been updated." : "Postavke su ažurirane.",
    "remote user" : "udaljeni korisnik",
    "Recent activity" : "Nedavna aktivnost",
    "No activities" : "Nema aktivnosti",
    "More activities" : "Više aktivnosti",
    "Daily activity summary for %s" : "Dnevni sažetak aktivnosti za %s",
    "_and %n more…_::_and %n more…_" : ["i još %n …","i još %n …","i još %n …"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Dnevne sažetke e-pošte možete onemogućiti u <a href=\"%s\">postavkama</a>.",
    "You can disable daily digest emails in the settings: %s" : "Dnevne sažetke e-pošte možete onemogućiti u postavkama: %s",
    "All activities" : "Sve aktivnosti",
    "By others" : "Od drugih",
    "By you" : "Vaše",
    "Activity at %s" : "Aktivnost na %s",
    "Hello %s" : "Pozdrav %s",
    "Hello %s," : "Pozdrav %s",
    "There was some activity at %s" : "Bilo je aktivnosti na %s",
    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u <a href=\"%s\">postavkama</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u postavkama: %s",
    "Mail" : "Pošta",
    "Push" : "Push",
    "Activity" : "Aktivnost",
    "Notifications" : "Obavijesti",
    "This application enables people to view a log of activities about them, their files or other data." : "Ova aplikacija omogućuje korisnicima pregled aktivnosti o njima, njihovim datotekama ili ostalim podacima.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ova aplikacija omogućuje ljudima da vide radnje povezane s njihovim datotekama i podacima u Nextcloudu.\n\t\tSvaka osoba može konfigurirati svoje individualne postavke aktivnosti u osobnim postavkama,\n\t\todabrati koje aktivnosti treba poslati na mobilne telefone, putem e-pošte\n\t\tili hoće li se dnevni sažetak slati svako jutro.\n\t\tViše informacija dostupno je u dokumentaciji o aktivnostima.",
    "Send email" : "Pošalji poruku e-pošte",
    "Send push notification" : "Pošalji \"push\" notifikaciju",
    "Activity notification configuration" : "Konfiguracija obavijesti o aktivnostima",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "You need to set up your email address before you can receive notification emails." : "Morate navesti svoju adresu e-pošte kako biste primali poruke s obavijestima.",
    "Send activity emails" : "Šalji e-poštu s pregledom aktivnosti",
    "As soon as possible" : "Čim prije moguće",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "You commented" : "Vi ste komentirali",
    "Message deleted by author" : "Autor je izbrisao poruku",
    "Open {filename}" : "Otvori {filename}",
    "in {path}" : "u {path}",
    "Home" : "Početna",
    "Could not load activities" : "Učitavanje aktivnosti nije uspjelo",
    "Loading activities" : "Učitavanje aktivnosti",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "No activity yet" : "Trenutno nema aktivnosti",
    "Loading more activities" : "Učitavanje više aktivnosti",
    "No more activities." : "Nema više aktivnosti.",
    "Could not enable RSS link" : "Nije moguće omogućiti RSS poveznicu",
    "RSS link copied to clipboard" : "RSS poveznica kopirana je u međuspremnik",
    "Could not copy the RSS link, please copy manually:" : "Nije moguće kopirati RSS poveznicu, kopirajte je ručno:",
    "Activity settings" : "Postavke Aktivnosti",
    "Enable RSS feed" : "Omogući sažetak događaja RSS",
    "RSS feed" : "Sažetak događaja RSS",
    "Copy RSS feed link" : "Kopiraj poveznicu sažetka događaja.",
    "Personal notification settings" : "Osobne postavke obavijesti",
    "Unable to load the activity list" : "Nije moguće učitati popis aktivnosti",
    "Choose for which activities you want to get an email or push notification." : "Odaberite za koje aktivnosti želite primati obavijest e-poštom ili push obavijesti.",
    "Choose for which activities you want to get a push notification." : "Odaberite za koje aktivnosti želite primati push obavijesti.",
    "Notification" : "Obavijest",
    "Enable notification emails" : "Omogući e-poštu s obavijestima",
    "Daily activity summary" : "Dnevni sažetak aktivnosti",
    "Send daily activity summary in the morning" : "Šalji dnevni sažetak aktivnosti ujutro",
    "Default settings" : "Zadane postavke",
    "Configure the default notification settings for new accounts." : "Konfiguriraj zadane postavke obavijesti za nove račune.",
    "Unable to save the settings" : "Nije moguće spremiti postavke",
    "No more events to load" : "Nema više događaja za učitavanje"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
